@@ -1,7 +1,7 @@
 package Perinci::Object::Metadata;
 
-our $DATE = '2014-12-11'; # DATE
-our $VERSION = '0.21'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.22'; # VERSION
 
 use 5.010;
 use strict;
@@ -65,7 +65,7 @@ sub langprop {
         if (defined $v) {
             if ($k->[2]) {
                 my $has_nl = $v =~ s/\n\z//;
-                $v = "{$k->[0] $v}" . ($has_nl ? "\n" : "");
+                $v = "{$olang|$k->[0] $v}" . ($has_nl ? "\n" : "");
             }
             $v = trim_blank_lines($v);
             last GET;
@@ -139,7 +139,7 @@ Perinci::Object::Metadata - Base class for Perinci::Object metadata classes
 
 =head1 VERSION
 
-This document describes version 0.21 of Perinci::Object::Metadata (from Perl distribution Perinci-Object), released on 2014-12-11.
+This document describes version 0.22 of Perinci::Object::Metadata (from Perl distribution Perinci-Object), released on 2015-09-03.
 
 =head1 METHODS
 
@@ -220,7 +220,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
